@@ -41,20 +41,20 @@
     will translate into a kas configuration:
 
      - kas configuration files that will be included when building the
-       generated configuration. Those are picked up from kconfig string
+       generated configuration. Those are picked up from Kconfig string
        variables that have the name prefix ``KAS_INCLUDE_``.
 
      - bitbake targets that shall be built via the generated configuration.
-       Those are picked up from kconfig string variables that have the name
+       Those are picked up from Kconfig string variables that have the name
        prefix ``KAS_TARGET_``.
 
-     - The ``build_system`` that will used. The static kconfig string variable
+     - The ``build_system`` that will used. The static Kconfig string variable
        ``KAS_BUILD_SYSTEM`` defines this value which must be ``openembedded``,
        ``oe`` or ``isar`` is set.
 
      - bitbake configuration variables that will be added to the
        ``local_conf_header`` section of the generated configuration. All other
-       active kconfig string, integer or hex variables are treated as such.
+       active Kconfig string, integer or hex variables are treated as such.
 
     See https://www.kernel.org/doc/html/latest/kbuild/kconfig-language.html
     for a complete documentation of the Kconfig language.
@@ -70,17 +70,22 @@ import logging
 import os
 import pprint
 import yaml
-from kconfiglib import Kconfig, Symbol, Choice, KconfigError, \
-    expr_value, TYPE_TO_STR, MENU, COMMENT, STRING, BOOL, INT, HEX, UNKNOWN
 from kas import __version__, __file_version__
 from kas.context import create_global_context
 from kas.config import CONFIG_YAML_FILE
 from kas.repos import Repo
-from kas.includehandler import load_config as load_config_yaml, \
+from kas.includehandler import ConfigFile, \
     SOURCE_DIR_OVERRIDE_KEY, SOURCE_DIR_HOST_OVERRIDE_KEY
 from kas.plugins.build import Build
 from kas.kasusererror import KasUserError, MissingModuleError
 
+try:
+    from kconfiglib import Kconfig, Symbol, Choice, KconfigError, \
+        expr_value, TYPE_TO_STR, MENU, COMMENT, STRING, BOOL, INT, HEX, UNKNOWN
+    HAVE_KCONFIGLIB = True
+except ImportError:
+    HAVE_KCONFIGLIB = False  # will be reported in run()
+
 try:
     from snack import SnackScreen, EntryWindow, ButtonChoiceWindow, \
         ButtonBar, Listbox, GridFormHelp
@@ -139,7 +144,8 @@ class Menu:
 
     def load_config(self, filename):
         try:
-            self.orig_config, _ = load_config_yaml(filename)
+            config = ConfigFile.load(filename)
+            self.orig_config = config.config
         except FileNotFoundError:
             self.orig_config = {}
             return
@@ -258,6 +264,8 @@ class Menu:
             self.kconf.warnings = []
 
     def run(self, args):
+        if not HAVE_KCONFIGLIB:
+            raise MissingModuleError('python3-kconfiglib', 'Menu plugin')
         if not HAVE_NEWT:
             raise MissingModuleError('python3-newt', 'Menu plugin')
 
