@@ -30,6 +30,7 @@ BITBAKE_OPTIONS_SHA256 = "e35d535e81cfdc4ed304af8000284c36" \
                          "19d2c4c78392ddcefe9ca46b158235f8"
 
 
+@pytest.mark.dirsfromenv
 def test_artifact_node(monkeykas, tmpdir):
     tdir = str(tmpdir / 'test_build')
     shutil.copytree('tests/test_build', tdir)
@@ -44,13 +45,15 @@ def test_provenance(monkeykas, tmpdir):
     tdir = str(tmpdir / 'test_build')
     shutil.copytree('tests/test_build', tdir)
     monkeykas.chdir(tdir)
+    kas_bd = monkeykas.get_kbd()
 
     with pytest.raises(ArtifactNotFoundError):
         kas.kas(['build', '--provenance', 'mode=min',
                  'artifact-invalid.yml'])
 
+    provenance_path = kas_bd / 'attestation/kas-build.provenance.json'
     kas.kas(['build', '--provenance', 'mode=min', 'provenance.yml'])
-    with open('build/attestation/kas-build.provenance.json', 'r') as f:
+    with open(provenance_path, 'r') as f:
         prov = json.load(f)
         assert prov['subject'][0]['name'] == 'bitbake.options'
         assert 'env' not in \
@@ -59,7 +62,7 @@ def test_provenance(monkeykas, tmpdir):
     with monkeykas.context() as mp:
         mp.setenv('CAPTURE_THIS', 'OK Sir!')
         kas.kas(['build', '--provenance', 'mode=max', 'provenance.yml'])
-    with open('build/attestation/kas-build.provenance.json', 'r') as f:
+    with open(provenance_path, 'r') as f:
         prov = json.load(f)
         params = prov['predicate']['buildDefinition']['internalParameters']
         assert params['env']['CAPTURE_THIS'] == 'OK Sir!'
