@@ -27,11 +27,16 @@ import pathlib
 import subprocess
 import re
 import pytest
+import json
+import logging
 from kas import kas
 from kas.context import create_global_context
-from kas.kasusererror import ArgsCombinationError
+from kas.kasusererror import ArgsCombinationError, EnvSetButNotFoundError
+from kas.libcmds import SetupHome
+from kas import __version__
 
 
+@pytest.mark.dirsfromenv
 def test_build_dir_is_placed_inside_work_dir_by_default(monkeykas, tmpdir):
     conf_dir = str(tmpdir / 'test_env_variables')
     shutil.copytree('tests/test_environment_variables', conf_dir)
@@ -40,7 +45,7 @@ def test_build_dir_is_placed_inside_work_dir_by_default(monkeykas, tmpdir):
 
     kas.kas(['checkout', 'test.yml'])
 
-    assert os.path.exists(os.path.join(os.getcwd(), 'build', 'conf'))
+    assert (monkeykas.get_kbd() / 'conf').exists()
 
 
 def test_build_dir_can_be_specified_by_environment_variable(monkeykas, tmpdir):
@@ -55,6 +60,7 @@ def test_build_dir_can_be_specified_by_environment_variable(monkeykas, tmpdir):
     assert os.path.exists(os.path.join(build_dir, 'conf'))
 
 
+@pytest.mark.dirsfromenv
 def test_ssh_agent_setup(monkeykas, tmpdir, capsys):
     conf_dir = str(tmpdir / 'test_ssh_agent_setup')
     shutil.copytree('tests/test_environment_variables', conf_dir)
@@ -109,16 +115,19 @@ def _get_env_from_file(filename):
 
 
 def _test_env_section_export(monkeykas, tmpdir, bb_env_var, bb_repo):
-    conf_dir = pathlib.Path(str(tmpdir / 'test_env_variables'))
+    conf_dir = tmpdir / 'test_env_variables'
     env_out = conf_dir / 'env_out'
     bb_env_out = conf_dir / 'bb_env_out'
     init_build_env = conf_dir / 'oe-init-build-env'
 
-    shutil.copytree('tests/test_environment_variables', str(conf_dir))
+    shutil.copytree('tests/test_environment_variables', conf_dir)
     monkeykas.chdir(conf_dir)
     monkeykas.setenv('KAS_CLONE_DEPTH', '1')
     monkeykas.setenv('KAS_PREMIRRORS', 'https://git\\.openembedded\\.org/ '
                      'https://github.com/openembedded/\n')
+    # resolve after we chdir'd
+    kas_wd = monkeykas.get_kwd()
+    kas_bd = monkeykas.get_kbd()
 
     # Overwrite oe-init-build-env script
     # BB_ENV_* filter variables are only exported by
@@ -126,14 +135,14 @@ def _test_env_section_export(monkeykas, tmpdir, bb_env_var, bb_repo):
     script = """#!/bin/sh
     export %s="FOO"
     export PATH="%s/%s/bin:${PATH}"
-    """ % (bb_env_var, str(conf_dir), bb_repo)
-    init_build_env.write_text(script)
+    """ % (bb_env_var, str(kas_wd), bb_repo)
+    init_build_env.write_text(script, encoding=None)
     init_build_env.chmod(0o775)
 
     # Before executing bitbake, first get the bitbake.conf
     kas.kas(['checkout', 'test_env.yml'])
-    shutil.copy(str(conf_dir / bb_repo / 'conf' / 'bitbake.conf'),
-                str(pathlib.Path('build') / 'conf' / 'bitbake.conf'))
+    shutil.copy(kas_wd / bb_repo / 'conf' / 'bitbake.conf',
+                kas_bd / 'conf' / 'bitbake.conf')
 
     kas.kas(['shell', '-c', 'env > %s' % env_out, 'test_env.yml'])
     kas.kas(['shell', '-c', 'bitbake -e > %s' % bb_env_out, 'test_env.yml'])
@@ -200,3 +209,71 @@ def test_managed_env_detection(monkeykas):
         assert bool(me)
         assert str(me) == 'VSCode Remote Containers'
         assert ctx.environ['REMOTE_CONTAINERS_FOO'] == 'bar'
+
+
+@pytest.mark.dirsfromenv
+def test_env_file_processing(monkeykas, tmpdir):
+    ctx = create_global_context([])
+    rcfiles = [
+        ('NETRC_FILE', '.netrc'),
+        ('NPMRC_FILE', '.npmrc'),
+        ('REGISTRY_AUTH_FILE', '.docker/config.json'),
+        ('AWS_CONFIG_FILE', '.aws/config'),
+        ('AWS_WEB_IDENTITY_TOKEN_FILE', '.aws/web_identity_token')
+        # no need to test gitconfig, as tested in test_gitconfig
+    ]
+    for name, file in rcfiles:
+        with monkeykas.context() as mp:
+            local_file = tmpdir / '.rcfile'
+            with open(local_file, 'w') as f:
+                if name in ['NETRC_FILE', 'NPMRC_FILE']:
+                    f.write('machine foo\nlogin bar\npassword baz\n')
+                elif name in ['AWS_CONFIG_FILE',
+                              'AWS_WEB_IDENTITY_TOKEN_FILE']:
+                    f.write('[profile foo]\nregion=bar\n')
+                elif name == 'REGISTRY_AUTH_FILE':
+                    json.dump({'auths': {'example.com': {'auth': 'foo'}}}, f)
+                else:
+                    f.write('foo: bar\n')
+            mp.setenv(name, str(local_file))
+            if name in ['AWS_CONFIG_FILE', 'AWS_WEB_IDENTITY_TOKEN_FILE']:
+                mp.setenv('AWS_SHARED_CREDENTIALS_FILE', str(local_file))
+                mp.setenv('AWS_ROLE_ARN', 'arn:foo')
+                if name == 'AWS_WEB_IDENTITY_TOKEN_FILE':
+                    mp.setenv('AWS_CONFIG_FILE', str(local_file))
+            elif name == 'REGISTRY_AUTH_FILE':
+                mp.setenv('CI_JOB_TOKEN', 'foo')
+                mp.setenv('CI_REGISTRY_USER', 'reg-user')
+                mp.setenv('CI_REGISTRY', 'example.com')
+            sh = SetupHome()
+            sh.execute(ctx)
+            assert (pathlib.Path(sh.tmpdirname) / pathlib.Path(file)).exists()
+
+
+def test_env_set_but_not_existing(monkeykas):
+    with monkeykas.context() as mp:
+        mp.setenv('NETRC_FILE', '/path/does/not/exist')
+        ctx = create_global_context([])
+        with pytest.raises(EnvSetButNotFoundError):
+            SetupHome().execute(ctx)
+
+
+def test_kas_container_version(monkeykas, caplog):
+    caplog.set_level(logging.WARNING)
+    with monkeykas.context() as mp:
+        # not a kas-container call
+        create_global_context([])
+        assert 'versions do not match' not in caplog.text
+        caplog.clear()
+    with monkeykas.context() as mp:
+        # kas-container call from matching script
+        mp.setenv('KAS_CONTAINER_SCRIPT_VERSION', __version__)
+        create_global_context([])
+        assert 'versions do not match' not in caplog.text
+        caplog.clear()
+    with monkeykas.context() as mp:
+        # kas-container call from older/newer script
+        mp.setenv('KAS_CONTAINER_SCRIPT_VERSION', '0.0')
+        create_global_context([])
+        assert 'versions do not match' in caplog.text
+        caplog.clear()
