@@ -28,7 +28,8 @@ import contextlib
 
 import pytest
 
-from kas import includehandler
+from kas import includehandler, context
+from kas.includehandler import ConfigFile
 
 
 @pytest.fixture(autouse=True)
@@ -37,6 +38,13 @@ def fixed_version(monkeypatch):
     monkeypatch.setattr(includehandler, '__compatible_file_version__', 4)
 
 
+@pytest.fixture(autouse=True)
+def with_kas_context():
+    context.create_global_context(None)
+    yield
+    context.__context__ = None
+
+
 class MockFileIO(io.StringIO):
     def close(self):
         self.seek(0)
@@ -63,13 +71,13 @@ class TestLoadConfig:
         # Test for invalid file extension:
         exception = includehandler.LoadConfigException
         with pytest.raises(exception):
-            includehandler.load_config('x.xyz')
+            ConfigFile.load('x.xyz')
 
     def util_exception_content(self, testvector):
         for string, exception in testvector:
             with patch_open(includehandler, string=string):
                 with pytest.raises(exception):
-                    includehandler.load_config('x.yml')
+                    ConfigFile.load('x.yml')
 
     def test_err_header_missing(self):
         exception = includehandler.LoadConfigException
@@ -113,6 +121,14 @@ class TestLoadConfig:
 
         self.util_exception_content(testvector)
 
+    def test_err_parse_yaml(self):
+        exception = includehandler.LoadConfigException
+        testvector = [
+            # misaligned column
+            ('header:\n  version: 17\n repo:', exception),
+        ]
+        self.util_exception_content(testvector)
+
     def test_header_valid(self):
         testvector = [
             'header: {version: 4}',
@@ -120,12 +136,12 @@ class TestLoadConfig:
         ]
         for string in testvector:
             with patch_open(includehandler, string=string):
-                includehandler.load_config('x.yml')
+                ConfigFile.load('x.yml')
 
     def test_compat_version(self, monkeypatch):
         monkeypatch.setattr(includehandler, '__compatible_file_version__', 1)
         with patch_open(includehandler, string='header: {version: "0.10"}'):
-            includehandler.load_config('x.yml')
+            ConfigFile.load('x.yml')
 
 
 class TestIncludes:
@@ -139,7 +155,7 @@ header:
         monkeypatch.setattr(includehandler, 'CONFIGSCHEMA', {})
         for test in testvector:
             with patch_open(includehandler, dictionary=test['fdict']):
-                ginc = includehandler.IncludeHandler(['x.yml'], '.')
+                ginc = includehandler.IncludeHandler(['x.yml'])
                 config, missing = ginc.get_config(repos=test['rdict'])
 
                 # Remove header, because we dont want to compare it:
@@ -148,6 +164,14 @@ header:
                 assert test['conf'] == config
                 assert test['rmiss'] == missing
 
+                if 'cfiles' in test:
+                    assert len(ginc.config_files) == len(test['cfiles'])
+
+                    for i, cf in enumerate(ginc.config_files):
+                        assert test['cfiles'][i][0] == str(cf.filename)
+                        assert test['cfiles'][i][1] == cf.is_lockfile
+                        assert test['cfiles'][i][2] == cf.is_external
+
     def test_valid_includes_none(self, monkeypatch):
         header = self.__class__.header
         testvector = [
@@ -160,6 +184,13 @@ header:
                 'conf': {
                 },
                 'rmiss': [
+                ],
+                'cfiles': [
+                    (
+                        'x.yml',
+                        False,
+                        False
+                    )
                 ]
             },
         ]
@@ -181,6 +212,18 @@ header:
                     'v': None
                 },
                 'rmiss': [
+                ],
+                'cfiles': [
+                    (
+                        os.path.abspath('y.yml'),
+                        False,
+                        False
+                    ),
+                    (
+                        'x.yml',
+                        False,
+                        False
+                    )
                 ]
             },
             # Include one file from another not available repo:
@@ -195,6 +238,13 @@ header:
                 },
                 'rmiss': [
                     'rep',
+                ],
+                'cfiles': [
+                    (
+                        'x.yml',
+                        False,
+                        False
+                    )
                 ]
             },
             # Include one file from the same repo and one from another
@@ -212,6 +262,18 @@ header:
                 },
                 'rmiss': [
                     'rep',
+                ],
+                'cfiles': [
+                    (
+                        os.path.abspath('y.yml'),
+                        False,
+                        False
+                    ),
+                    (
+                        'x.yml',
+                        False,
+                        False
+                    )
                 ]
             },
             # Include one file from another available repo:
@@ -228,6 +290,18 @@ header:
                     'v': None
                 },
                 'rmiss': [
+                ],
+                'cfiles': [
+                    (
+                        '/rep/y.yml',
+                        False,
+                        True
+                    ),
+                    (
+                        'x.yml',
+                        False,
+                        False
+                    )
                 ]
             },
             # Include two files from another repo in sub-directories:
@@ -246,6 +320,23 @@ header:
                     'v': None
                 },
                 'rmiss': [
+                ],
+                'cfiles': [
+                    (
+                        '/rep/dir2/z.yml',
+                        False,
+                        True
+                    ),
+                    (
+                        '/rep/dir1/y.yml',
+                        False,
+                        True
+                    ),
+                    (
+                        'x.yml',
+                        False,
+                        False
+                    )
                 ]
             },
         ]
@@ -365,7 +456,7 @@ v: {v2: y, v3: y, v5: y}'''),
                 os.path.abspath('z.yml'): header.format('''
 v: {v3: z, v4: z}''')}
         with patch_open(includehandler, dictionary=data):
-            ginc = includehandler.IncludeHandler(['x.yml'], '.')
+            ginc = includehandler.IncludeHandler(['x.yml'])
             config, _ = ginc.get_config()
             keys = list(config['v'].keys())
             index = {keys[i]: i for i in range(len(keys))}
